@@ -5,8 +5,8 @@
     arithmetic_overflow,
     array_into_iter,
     asm_sub_register,
+    bad_asm_style,
     bindings_with_variant_name,
-    broken_intra_doc_links,
     cenum_impl_drop_cast,
     clashing_extern_declarations,
     coherence_leak_check,
@@ -18,10 +18,13 @@
     dead_code,
     deprecated,
     deprecated_in_future,
+    deref_nullptr,
     drop_bounds,
+    dyn_drop,
     ellipsis_inclusive_range_patterns,
     explicit_outlives_requirements,
     exported_private_dependencies,
+    forbidden_lint_groups,
     function_item_references,
     ill_formed_attribute_input,
     illegal_floating_point_literal_pattern,
@@ -30,18 +33,20 @@
     incomplete_features,
     incomplete_include,
     indirect_structural_match,
+    ineffective_unstable_trait_impl,
     inline_no_sanitize,
-    invalid_codeblock_attributes,
+    invalid_doc_attributes,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
     keyword_idents,
+    large_assignments,
     late_bound_lifetime_arguments,
+    legacy_derive_helpers,
     macro_expanded_macro_exports_accessed_by_absolute_paths,
     meta_variable_misuse,
     missing_abi,
     missing_copy_implementations,
-    missing_crate_level_docs,
     missing_docs,
     missing_fragment_specifier,
     mixed_script_confusables,
@@ -50,26 +55,29 @@
     no_mangle_const_items,
     no_mangle_generic_items,
     non_ascii_idents,
-    non_autolinks,
     non_camel_case_types,
+    non_fmt_panics,
     non_shorthand_field_patterns,
     non_snake_case,
     non_upper_case_globals,
     nontrivial_structural_match,
+    noop_method_call,
     order_dependent_trait_objects,
     overflowing_literals,
     overlapping_range_endpoints,
-    panic_fmt,
     path_statements,
     patterns_in_fns_without_body,
     pointer_structural_match,
-    private_doc_tests,
     private_in_public,
-    private_intra_doc_links,
+    proc_macro_back_compat,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
     redundant_semicolons,
-    safe_packed_borrows,
+    rust_2021_incompatible_closure_captures,
+    rust_2021_incompatible_or_patterns,
+    rust_2021_prefixes_incompatible_syntax,
+    rust_2021_prelude_collisions,
+    semicolon_in_expressions_from_macros,
     soft_unstable,
     stable_features,
     temporary_cstring_as_ptr,
@@ -89,8 +97,10 @@
     unreachable_patterns,
     unreachable_pub,
     unsafe_code,
+    unsafe_op_in_unsafe_fn,
     unstable_features,
     unstable_name_collisions,
+    unsupported_calling_conventions,
     unsupported_naked_functions,
     unused_allocation,
     unused_assignments,
@@ -112,17 +122,13 @@
     unused_qualifications,
     unused_unsafe,
     unused_variables,
-    useless_deprecated,
-    where_clauses_object_safety,
-    while_true
+    useless_deprecated
 )]
 #![warn(macro_use_extern_crate, unknown_lints)]
 #![allow(
     bare_trait_objects,
     box_pointers,
-    invalid_html_tags,
     elided_lifetimes_in_paths,
-    missing_doc_code_examples,
     missing_debug_implementations,
     single_use_lifetimes,
     unused_results,
